import numpy as np
import pandas as pd
from baikal import Step
from sklearn.base import TransformerMixin


class PandasConcat(Step):
    def __init__(self, df_out=True, name=None):
        super().__init__(name=name)
        self.df_out = df_out

    def fit(self, *args, **kwargs):
        return self

    def transform(self, Xs):
        df = pd.concat(Xs, axis=1, ignore_index=False)
        return df if self.df_out else df.values


class To2D(TransformerMixin):
    def fit(self, X, y=None):
        return self

    def transform(self, X, y=None, **kwargs):
        return X.reshape(-1, 1)


class AsStr(TransformerMixin):
    def fit(self, X, y=None):
        return self

    def transform(self, X, y=None, **kwargs):
        return X.astype(np.str)


class ToDense(TransformerMixin):
    def fit(self, X, y=None):
        return self

    def transform(self, X, y=None, **kwargs):
        return X.todense()



from baikal import Step
from sklearn_pandas import DataFrameMapper


class DataFrameMapperStep(Step, DataFrameMapper):

    def __init__(self, *args, name=None, n_outputs=1, **kwargs):
        super().__init__(*args, name=name, n_outputs=n_outputs, **kwargs)
        self._nodes = []

    def __getstate__(self):
        state = super().__getstate__()
        state["_name"] = self._name
        state["_nodes"] = self._nodes
        state["_n_outputs"] = self._n_outputs
        return state

    def __setstate__(self, state):
        self._name = state["_name"]
        self._nodes = state["_nodes"]
        self._n_outputs = state["_n_outputs"]
        super().__setstate__(state)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup
import re

for line in open('mlplumber/__init__.py'):
    match = re.match("__version__ *= *'(.*)'", line)
    if match:
        __version__, = match.groups()


setup(name='mlplumber',
      version=__version__,
      description='ML Utilities for constructing pipeline',
      maintainer='Ritesh Agrawal',
      maintainer_email='ragrawal@gmail.com',
      url='https://github.com/ragrawal/mlplumber',
      packages=['mlplumber'],
      keywords=['scikit', 'sklearn', 'pandas', 'baikal'],
      setup_requires=['flake8'],
      install_requires=[
          'sklearn-pandas>=2.0.0',
          'baikal>=0.4.1'
      ],
      tests_require=['pytest']
      )
